import { __decorate } from 'tslib';
import 'bootstrap-datepicker';
import { forwardRef, Input, ViewChild, Component, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CommonModule } from '@angular/common';

const BASE_OPTION = {
    autoclose: true,
    format: "dd/mm/yyyy",
    language: "en-GB",
};
const th_TH = Object.assign({}, BASE_OPTION, { language: "th-TH" });
const en_GB = Object.assign({}, BASE_OPTION, { language: "en-GB" });
const NGQ_DATETIME_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgqDatepickerComponent),
    multi: true,
};
let NgqDatepickerComponent = class NgqDatepickerComponent {
    constructor() {
        this.propagateChange = (_) => { };
    }
    // should re-initial datepicker when assign new options
    set opts(opts) {
        this._opts = opts;
        if (this._jQueryElement) {
            this._jQueryElement.datepicker("destroy");
            const newVal = !!this._value
                ? new Intl.DateTimeFormat(this._opts.language).format(this._value)
                : "";
            this._jQueryElement.val(newVal);
            this.initDatepicker();
        }
    }
    ngAfterViewInit() {
        this._jQueryElement = jQuery(this.input.nativeElement);
        this.initDatepicker();
    }
    initDatepicker() {
        this._opts = this._opts ? this._opts : th_TH;
        this._jQueryElement.datepicker(this._opts);
        this._jQueryElement.datepicker().on("changeDate", (e) => {
            this._value = e.date;
            this.propagateChange(this._value);
        });
        this._jQueryElement.datepicker("update", this._value ? new Date(Number(this._value)) : null);
        this._jQueryElement.prop("disabled", this._isDisabled);
    }
    onChange(value) {
        if (!value) {
            this._value = null;
            this.propagateChange(this._value);
        }
        else {
            if (this._jQueryElement) {
                this._jQueryElement.datepicker("destroy");
                this.initDatepicker();
            }
        }
    }
    writeValue(obj) {
        this._value = obj;
        if (this._jQueryElement) {
            console.log(this._value);
            this._jQueryElement.datepicker("update", this._value ? new Date(Number(this._value)) : null);
        }
    }
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    registerOnTouched(fn) { }
    setDisabledState(isDisabled) {
        this._isDisabled = isDisabled;
        if (this._jQueryElement) {
            this._jQueryElement.prop("disabled", this._isDisabled);
        }
    }
};
__decorate([
    Input()
], NgqDatepickerComponent.prototype, "hideIcon", void 0);
__decorate([
    Input()
], NgqDatepickerComponent.prototype, "id", void 0);
__decorate([
    Input()
], NgqDatepickerComponent.prototype, "class", void 0);
__decorate([
    Input()
], NgqDatepickerComponent.prototype, "placeholder", void 0);
__decorate([
    ViewChild("input", { static: false })
], NgqDatepickerComponent.prototype, "input", void 0);
__decorate([
    Input("opts")
], NgqDatepickerComponent.prototype, "opts", null);
NgqDatepickerComponent = __decorate([
    Component({
        selector: "ngq-datepicker",
        template: "<div *ngIf=\"!hideIcon\" class=\"input-group\">\n  <input #input type=\"text\" [attr.class]=\"class\" [attr.id]=\"id\" [attr.placeholder]=\"placeholder\" (change)=\"onChange($event.target.value)\">\n  <div class=\"input-group-append\" (click)=\"_jQueryElement.datepicker('show')\">\n    <a class=\"input-group-text\">\n      <i class=\"fas fa-calendar-alt\"></i>\n    </a>\n  </div>\n</div>\n\n<input *ngIf=\"hideIcon\" #input type=\"text\" [attr.class]=\"class\" [attr.id]=\"id\" [attr.placeholder]=\"placeholder\" (change)=\"onChange($event.target.value)\">\n",
        providers: [NGQ_DATETIME_VALUE_ACCESSOR],
        styles: [":host{outline:0}"]
    })
], NgqDatepickerComponent);

let NgqDatepickerModule = class NgqDatepickerModule {
};
NgqDatepickerModule = __decorate([
    NgModule({
        imports: [CommonModule],
        declarations: [NgqDatepickerComponent],
        exports: [NgqDatepickerComponent]
    })
], NgqDatepickerModule);

/**
 * Generated bundle index. Do not edit.
 */

export { BASE_OPTION, NgqDatepickerComponent, NgqDatepickerModule, en_GB, th_TH };
//# sourceMappingURL=ngq-datepicker.js.map
