import { __assign, __decorate } from 'tslib';
import 'bootstrap-datepicker';
import { forwardRef, Input, ViewChild, Component, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CommonModule } from '@angular/common';

var BASE_OPTION = {
    autoclose: true,
    format: "dd/mm/yyyy",
    language: "en-GB",
};
var th_TH = __assign({}, BASE_OPTION, { language: "th-TH" });
var en_GB = __assign({}, BASE_OPTION, { language: "en-GB" });
var NGQ_DATETIME_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return NgqDatepickerComponent; }),
    multi: true,
};
var NgqDatepickerComponent = /** @class */ (function () {
    function NgqDatepickerComponent() {
        this.propagateChange = function (_) { };
    }
    Object.defineProperty(NgqDatepickerComponent.prototype, "opts", {
        // should re-initial datepicker when assign new options
        set: function (opts) {
            this._opts = opts;
            if (this._jQueryElement) {
                this._jQueryElement.datepicker("destroy");
                var newVal = !!this._value
                    ? new Intl.DateTimeFormat(this._opts.language).format(this._value)
                    : "";
                this._jQueryElement.val(newVal);
                this.initDatepicker();
            }
        },
        enumerable: true,
        configurable: true
    });
    NgqDatepickerComponent.prototype.ngAfterViewInit = function () {
        this._jQueryElement = jQuery(this.input.nativeElement);
        this.initDatepicker();
    };
    NgqDatepickerComponent.prototype.initDatepicker = function () {
        var _this = this;
        this._opts = this._opts ? this._opts : th_TH;
        this._jQueryElement.datepicker(this._opts);
        this._jQueryElement.datepicker().on("changeDate", function (e) {
            _this._value = e.date;
            _this.propagateChange(_this._value);
        });
        this._jQueryElement.datepicker("update", this._value ? new Date(Number(this._value)) : null);
        this._jQueryElement.prop("disabled", this._isDisabled);
    };
    NgqDatepickerComponent.prototype.onChange = function (value) {
        if (!value) {
            this._value = null;
            this.propagateChange(this._value);
        }
        else {
            if (this._jQueryElement) {
                this._jQueryElement.datepicker("destroy");
                this.initDatepicker();
            }
        }
    };
    NgqDatepickerComponent.prototype.writeValue = function (obj) {
        this._value = obj;
        if (this._jQueryElement) {
            console.log(this._value);
            this._jQueryElement.datepicker("update", this._value ? new Date(Number(this._value)) : null);
        }
    };
    NgqDatepickerComponent.prototype.registerOnChange = function (fn) {
        this.propagateChange = fn;
    };
    NgqDatepickerComponent.prototype.registerOnTouched = function (fn) { };
    NgqDatepickerComponent.prototype.setDisabledState = function (isDisabled) {
        this._isDisabled = isDisabled;
        if (this._jQueryElement) {
            this._jQueryElement.prop("disabled", this._isDisabled);
        }
    };
    __decorate([
        Input()
    ], NgqDatepickerComponent.prototype, "hideIcon", void 0);
    __decorate([
        Input()
    ], NgqDatepickerComponent.prototype, "id", void 0);
    __decorate([
        Input()
    ], NgqDatepickerComponent.prototype, "class", void 0);
    __decorate([
        Input()
    ], NgqDatepickerComponent.prototype, "placeholder", void 0);
    __decorate([
        ViewChild("input", { static: false })
    ], NgqDatepickerComponent.prototype, "input", void 0);
    __decorate([
        Input("opts")
    ], NgqDatepickerComponent.prototype, "opts", null);
    NgqDatepickerComponent = __decorate([
        Component({
            selector: "ngq-datepicker",
            template: "<div *ngIf=\"!hideIcon\" class=\"input-group\">\n  <input #input type=\"text\" [attr.class]=\"class\" [attr.id]=\"id\" [attr.placeholder]=\"placeholder\" (change)=\"onChange($event.target.value)\">\n  <div class=\"input-group-append\" (click)=\"_jQueryElement.datepicker('show')\">\n    <a class=\"input-group-text\">\n      <i class=\"fas fa-calendar-alt\"></i>\n    </a>\n  </div>\n</div>\n\n<input *ngIf=\"hideIcon\" #input type=\"text\" [attr.class]=\"class\" [attr.id]=\"id\" [attr.placeholder]=\"placeholder\" (change)=\"onChange($event.target.value)\">\n",
            providers: [NGQ_DATETIME_VALUE_ACCESSOR],
            styles: [":host{outline:0}"]
        })
    ], NgqDatepickerComponent);
    return NgqDatepickerComponent;
}());

var NgqDatepickerModule = /** @class */ (function () {
    function NgqDatepickerModule() {
    }
    NgqDatepickerModule = __decorate([
        NgModule({
            imports: [CommonModule],
            declarations: [NgqDatepickerComponent],
            exports: [NgqDatepickerComponent]
        })
    ], NgqDatepickerModule);
    return NgqDatepickerModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { BASE_OPTION, NgqDatepickerComponent, NgqDatepickerModule, en_GB, th_TH };
//# sourceMappingURL=ngq-datepicker.js.map
